//
//  SCSDataManager.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/2/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import Foundation
import SciChart

class SCSDataManager {
    
    
    
    static func loadData<DataSeriesType: SCIXyDataSeriesProtocol>(intoDataSeries dataSeries: DataSeriesType,
                         fileName: String,
                         startIndex: Int,
                         increment: Int,
                         reverse: Bool) {
        
        
        if let resourcePath = NSBundle.mainBundle().resourcePath {
            let filePath = resourcePath+"/"+fileName+".txt"
            do {
                let contentFile = try NSString(contentsOfFile: filePath, usedEncoding: nil) as String
                
                let items = contentFile.componentsSeparatedByString("\n")
                
                let dateFormatter = NSDateFormatter()
                dateFormatter.dateFormat = "YYYY-MM-dd"
                
                
                
                if reverse {
                    var i = items.count-1
                    while i >= startIndex {
                        
                        let subItems = items[i].componentsSeparatedByString(",")
                        
                        let date = dateFormatter.dateFromString(subItems[0])
                        let value = Float(subItems[1])
                        
                        dataSeries.appendX(SCIGeneric(date), y: SCIGeneric(value))
                        
                        i = i - increment
                    }
                    
                }
                else {
                   var i = startIndex
                    while i < items.count  {
                        
                        let subItems = items[i].componentsSeparatedByString(",")
                        
                        let date = dateFormatter.dateFromString(subItems[0])
                        let value = Float(subItems[1])
                        
                        dataSeries.appendX(SCIGeneric(date), y: SCIGeneric(value))
                        
                        i = i + 1
                    }
                }
            }
            catch {
                
                
            }
        }
    }
    
    static func putDataInto(dataSeries: SCIXyDataSeries) {
        let dataCount = 20
        var i = 0
        while i <= dataCount {
            let x = 10.0*Float(i)/Float(dataCount)
            let y = arc4random_uniform(UInt32(dataCount))
            let xValue = Float(x)
            let yValue = Float(y)
            dataSeries.appendX(SCIGeneric(xValue), y: SCIGeneric(yValue))
            i = i + 1
        }
    }
    
    static func putFourierDataInto(dataSeries: SCIXyDataSeries) {
        let dataCount = 1000
        var i = 0
        while i <= dataCount {
            let x = Float(10.0*Float(i)/Float(dataCount))
            let y = 2 * sin(x)+10
            dataSeries.appendX(SCIGeneric(x), y: SCIGeneric(y))
            i = i + 1
        }
    }
    
    static func getDampedSinewave(amplitude: Double, phase: Double, dampingFactor: Double, pointCount: Int, freq: Int) -> SCIXyDataSeries {

        let dataSeries = SCIXyDataSeries(XType: .Float, YType: .Float);
        var amplitudeMutable = amplitude
        var i = 0
        while i < pointCount {
            
            let time = 10.0 * Double(i) / Double(pointCount)
            let wn = 2.0 * M_PI / (Double(pointCount) / Double(freq))
            
            let d = amplitudeMutable * sin(Double(i) * wn + phase)
            
            dataSeries.appendX(SCIGeneric(time), y: SCIGeneric(d))
            
            amplitudeMutable *= (1.0 - dampingFactor)
            
            i += 1
        }

        return dataSeries;
    }
    
    static func randomize(min: Double, max: Double) -> Double {
        return (Double(arc4random()) / 0x100000000) * (max - min) + min
    }

}
