//
//  SCSBandChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/6/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import Foundation
import SciChart

class SCSBandChartView: SCSBaseChartView {
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxis()
        addModifiers()
        addDataSeries()
    }
    
    func addModifiers() {
        
        let xAxisDragmodifier = SCIXAxisDragModifier()
        xAxisDragmodifier.modifierName = xAxisDragModifierName
        xAxisDragmodifier.axisId = axisXId
        xAxisDragmodifier.dragMode = .Scale
        xAxisDragmodifier.clipModeX = .None
        
        let yAxisDragmodifier = SCIYAxisDragModifier()
        yAxisDragmodifier.modifierName = yAxisDragModifierName
        yAxisDragmodifier.axisId = axisYId
        yAxisDragmodifier.dragMode = .Pan
        
        let extendZoomModifier = SCIZoomExtentsModifier()
        extendZoomModifier.modifierName = extendZoomModifierName
        
        let pinchZoomModifier = SCIPinchZoomModifier()
        pinchZoomModifier.modifierName = pinchZoomModifierName
        
        let rolloverModifier = SCIRolloverModifier()
        rolloverModifier.modifierName = rolloverModifierName
//        rolloverModifier.style.tooltipSize = CGSizeMake(200, CGFloat.NaN)
        
        let groupModifier = SCIModifierGroup(childModifiers: [xAxisDragmodifier, yAxisDragmodifier, pinchZoomModifier, extendZoomModifier, rolloverModifier])
        
        chartSurface.chartModifier = groupModifier
    }
    
    // MARK: Private Functions
    
    private func addAxis() {
        let axisStyle = generateDefaultAxisStyle()
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
    }
    
    private func addDataSeries() {
        
        let dataSeries = SCIXyyDataSeries(XType: .Double, YType: .Double)
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        fillDataInto(dataSeries)
        
        let renderebleDataSeries = SCIBandRenderableSeries()
        renderebleDataSeries.style.brush1 = SCIBrushSolid(colorCode: 0x50279b27)
        renderebleDataSeries.style.brush2 = SCIBrushSolid(colorCode: 0x501919ff)
        renderebleDataSeries.style.pen1 = SCIPenSolid(colorCode: 0xFF279b27, width: 0.5)
        renderebleDataSeries.style.pen2 = SCIPenSolid(colorCode: 0xFF1919ff, width: 0.5)
        renderebleDataSeries.style.drawPointMarkers = false
        renderebleDataSeries.xAxisId = axisXId
        renderebleDataSeries.yAxisId = axisYId
        renderebleDataSeries.dataSeries = dataSeries
        
        chartSurface.attachRenderableSeries(renderebleDataSeries)
        
    }
    
    private func fillDataInto(dataSeries: SCIXyyDataSeries) {
        
        var i = 0
        while i < 500 {
            
            let time = 10.0 * Float(i) / 500.0
            let wn = 2.0 * M_PI / (500.0 / 3.0)
            
            dataSeries.appendX(SCIGeneric(time),
                               y1: SCIGeneric(0.03 * sin(Double(i) * wn + 4)),
                               y2: SCIGeneric(0.05 * sin(Double(i) * wn + 12)))
            
            i += 1
            
        }
        
    }
    
    
}
