//
//  SCSBubbleChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/3/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import Foundation
import SciChart

class SCSBubbleChartView: SCSBaseChartView  {
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxis()
        addModifiers()
        addDataSeries()
    }
    
    func addModifiers() {
        
        let xAxisDragmodifier = SCIXAxisDragModifier()
        xAxisDragmodifier.modifierName = xAxisDragModifierName
        xAxisDragmodifier.axisId = axisXId
        xAxisDragmodifier.dragMode = .Scale
        xAxisDragmodifier.clipModeX = .None
        
        let yAxisDragmodifier = SCIYAxisDragModifier()
        yAxisDragmodifier.modifierName = yAxisDragModifierName
        yAxisDragmodifier.axisId = axisYId
        yAxisDragmodifier.dragMode = .Pan
        
        let extendZoomModifier = SCIZoomExtentsModifier()
        extendZoomModifier.modifierName = extendZoomModifierName
        
        let pinchZoomModifier = SCIPinchZoomModifier()
        pinchZoomModifier.modifierName = pinchZoomModifierName
        
        let tooltipModifier = SCITooltipModifier()
        tooltipModifier.modifierName = "TooltipModifier"
        tooltipModifier.style.colorMode = .SeriesColor
        //        rolloverModifier.style.tooltipSize = CGSizeMake(200, CGFloat.NaN)
        
        let groupModifier = SCIModifierGroup(childModifiers: [xAxisDragmodifier, yAxisDragmodifier, pinchZoomModifier, extendZoomModifier, tooltipModifier])
        
        chartSurface.chartModifier = groupModifier
    }
    
    // MARK: Private Functions
    
    private func addAxis() {
        let axisStyle = generateDefaultAxisStyle()
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
    }
    
    private func addDataSeries() {
        let dataSeries = SCIXyzDataSeries(XType: .Float, YType: .Float, ZType: .Float)
        putDataInto(dataSeries)
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let bubbleRenderable = SCIBubbleRenderableSeries()
        bubbleRenderable.style.bubbleBrush = SCIBrushSolid(colorCode: 0xFF3f3bd6)
        bubbleRenderable.style.borderPen = SCIPenSolid(colorCode: 0xFF99EE99, width: 0.7)
        bubbleRenderable.style.detalization = 44
        bubbleRenderable.xAxisId = axisXId
        bubbleRenderable.yAxisId = axisYId
        bubbleRenderable.zScale = 3.0
        bubbleRenderable.dataSeries = dataSeries
        
        
        chartSurface.attachRenderableSeries(bubbleRenderable)
        chartSurface.invalidateElement()
        
    }
    
    private func putDataInto(dataSeries: SCIXyzDataSeries) {
        var i = 0
        while i < 20 {
            dataSeries.appendX(SCIGeneric(Float(i)),
                               y: SCIGeneric(sin(Float(i))),
                               z: SCIGeneric(Float(arc4random()%30)))
            i += 1
        }
    }
    
    
}
