//
//  SCSCandlestickChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/2/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import Foundation
import SciChart

class SCSCandlestickChartView: SCSBaseChartView {
    
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxis()
        addDefaultModifiers()
        addDataSeries()
    }
    
    // MARK: Private Functions
    
    private func addAxis() {
        let axisStyle = generateDefaultAxisStyle()
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
    }
    
    private func addDataSeries() {
        let upBrush = SCIBrushSolid(colorCode: 0xFF0f9cff)
        let downBrush = SCIBrushSolid(colorCode: 0xFF66ffff)
        let upWickPen = SCIPenLinearGradient(colorCodeStart: 0xFF16aff9, finish: 0xFF16aff9, direction: .Vertical, width: 0.2)
        let downWickPen = SCIPenLinearGradient(colorCodeStart: 0xFF16aff9, finish: 0xFF16aff9, direction: .Vertical, width: 0.7)
        
        chartSurface.attachRenderableSeries(getCandleRenderSeries(false, upBodyBrush: upBrush, upWickPen: upWickPen, downBodyBrush: downBrush, downWickPen: downWickPen, count: 30))
        
        chartSurface.invalidateElement()
        
        
        
    }
    
    private func getCandleRenderSeries(isReverse: Bool,
                                       upBodyBrush: SCIBrushSolid,
                                       upWickPen: SCIPenLinearGradient,
                                       downBodyBrush: SCIBrushSolid,
                                       downWickPen: SCIPenLinearGradient,
                                       count: Int) -> SCIFastCandlestickRenderableSeries {
        
        
        let ohlcDataSeries = SCIOhlcDataSeries(XType: .Float, YType: .Float)
        
        
        DataManager.loadPriceData(ohlcDataSeries,
                                  fileName: "FinanceData",
                                  isReversed: isReverse,
                                  count: Int32(count))
        
        ohlcDataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let candleRendereSeries = SCIFastCandlestickRenderableSeries()
        candleRendereSeries.xAxisId = axisXId
        candleRendereSeries.yAxisId = axisYId
        candleRendereSeries.dataSeries = ohlcDataSeries
        candleRendereSeries.style.drawBorders = true
        candleRendereSeries.style.upBodyBrush = upBodyBrush
        candleRendereSeries.style.downBodyBrush = downBodyBrush
        candleRendereSeries.style.upWickPen = upWickPen
        candleRendereSeries.style.downWickPen = downWickPen
        
        
        return candleRendereSeries
    }
    
}
