//
//  SCSLineChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 5/30/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import UIKit
import SciChart

class CustomRenderableSeries : SCICustomRenderableSeries {
    
    var columnWidth : Float = 20;
    var stripeSize  : Float = 5;
    var stripeSpace : Float = 2;
    var fillBrush : SCIBrush2D! = nil;
    var highlightBrush : SCIBrush2D! = nil;
    
    override init() {
        super.init();
        self.zeroLineY = 0.0;
    }
    
    override func internalDrawWithContext(renderContext: SCIRenderContext2D!, withData renderPassData: SCIRenderPassDataProtocol!) {
        let points = renderPassData.pointSeries();
        let xData = points.xValues();
        let yData = points.yValues();
        let indexData = points.indices();
        let zeroLine = Float(self.getYZeroCoord());
        for i in 0..<points.count() {
            let x = renderPassData.xCoordinateCalculator().getCoordinateFrom(SCIGenericDouble(xData.valueAt(Int(i))))
            let y = renderPassData.yCoordinateCalculator().getCoordinateFrom(SCIGenericDouble(yData.valueAt(Int(i))))
            let brush = (SCIGenericInt(indexData.valueAt(Int(i)))) == renderPassData.dataSeries().count()-1 ? highlightBrush : fillBrush ;
            fillColumn(renderContext, fillBrush: brush, x: Float(x), y: Float(y), width: columnWidth, height: abs(Float(y)-zeroLine));
        }
    }
    
    func fillColumn(renderContext: SCIRenderContext2D!, fillBrush : SCIBrush2D, x : Float, y : Float, width : Float, height : Float) {
        fillBrush .setDrawingAreaX(Double(x), y: Double(y), width: Double(width), height: Double(height));
        var currentY = y + height;
        let stripeStep = stripeSize + stripeSpace;
        let halfWidth = width / 2;
        while (currentY - stripeStep > y) {
            renderContext .drawRectWithBrush(fillBrush, fromX: x - halfWidth, y: currentY, toX: x + halfWidth, y: currentY - stripeSize);
            currentY -= stripeStep;
        }
    }
}

class SCSCustomChartView: SCSBaseChartView {
    
    // MARK: Overrided Functions
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxes()
        addSeries()
    }
    
    // MARK: Private Functions

    private func addAxes() {
 
        let axisStyle = generateDefaultAxisStyle()
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        let axis = SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId)
        axis.autoRange = .Once
        
        chartSurface.attachAxis(axis, isXAxis: false)
        
        
        addDefaultModifiers()

    }
    
    private func addSeries() {
        
        let dataSeries = SCIXyDataSeries(XType: .Float, YType: .Float)
        SCSDataManager.putDataInto(dataSeries)
        
        let fourierDataSeries = SCIXyDataSeries(XType: .Float, YType: .Float)
        SCSDataManager.putFourierDataInto(fourierDataSeries)
        
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        fourierDataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let columns = CustomRenderableSeries()
        columns.dataSeries = dataSeries
        columns.xAxisId = axisXId
        columns.yAxisId = axisYId
        columns.fillBrush = SCIBrushSolid(color: UIColor.cyanColor());
        columns.highlightBrush = SCIBrushLinearGradient(colorStart: UIColor.whiteColor(), finish: UIColor.blueColor(), direction: .Vertical);
        chartSurface.attachRenderableSeries(columns)
        
        chartSurface.invalidateElement()
        
    }
    
}
