//
//  SCSMultipleAxesChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/6/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import Foundation
import SciChart

class SCSMultipleAxesChartView: SCSBaseChartView {
    
    let axisX2Id = "axisX2Id"
    let axisY2Id = "axisY2Id"
    
    
    override func completeConfiguration() {
        super.completeConfiguration()
        addAxes()
        addSeries()
        addDefaultModifiers()
    }
    
    override func addDefaultModifiers() {
        super.addDefaultModifiers()
        addAditionalModifiers()
    }
    
    // MARK: Private Functions
    
    private func addAditionalModifiers() {
        
        let x2Pinch = SCIAxisPinchZoomModifier()
        x2Pinch.axisId = axisX2Id
        
        let x2Drag = SCIXAxisDragModifier()
        x2Drag.axisId = axisX2Id
        x2Drag.dragMode = .Scale
        x2Drag.clipModeX = .None
        
        let y2Pinch = SCIAxisPinchZoomModifier()
        y2Pinch.axisId = axisY2Id
        
        let y2Drag = SCIYAxisDragModifier()
        y2Drag.axisId = axisY2Id
        y2Drag.dragMode = .Pan
        
        let panZoom = SCIZoomPanModifier()
        
        if let gm = chartSurface.chartModifier as? SCIModifierGroup  {
            
            gm.removeItem(gm.itemByName(rolloverModifierName))
            gm.addItem(x2Drag)
            gm.addItem(x2Pinch)
            gm.addItem(y2Drag)
            gm.addItem(y2Pinch)
            gm.addItem(panZoom)
        }
        
        
    }
    
    private func addAxes() {
        
        let axisStyle = generateDefaultAxisStyle()
        
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisXId), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisYId), isXAxis: false)
        addDefaultModifiers()
        
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisX2Id), isXAxis: true)
        chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: axisY2Id), isXAxis: false)
        addDefaultModifiers()
        
    }
    
    private func addSeries() {
        
        let dataSeries = SCIXyDataSeries(XType: .Float, YType: .Float)
        SCSDataManager.putDataInto(dataSeries)
        dataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let fourierDataSeries = SCIXyDataSeries(XType: .Float, YType: .Float)
        SCSDataManager.putDataInto(fourierDataSeries)
        fourierDataSeries.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let ellipsePointMarker = SCIEllipsePointMarker()
        ellipsePointMarker.drawBorder = true
        ellipsePointMarker.fillBrush = SCIBrushSolid(colorCode: 0xFFd6ffd7)
        ellipsePointMarker.height = 5
        ellipsePointMarker.width = 5
        
        let priceRenderableSeries = SCIFastLineRenderableSeries()
        priceRenderableSeries.style.pointMarker = ellipsePointMarker
        priceRenderableSeries.style.drawPointMarkers = true
        priceRenderableSeries.style.linePen = SCIPenSolid(colorCode: 0xFF99EE99, width: 0.7)
        priceRenderableSeries.xAxisId = axisXId
        priceRenderableSeries.yAxisId = axisYId
        priceRenderableSeries.dataSeries = dataSeries
        chartSurface.attachRenderableSeries(priceRenderableSeries)
        
        let fourierRenderableSeries = SCIFastLineRenderableSeries()
        fourierRenderableSeries.style.linePen = SCIPenSolid(colorCode: 0xFF4c8aff, width: 0.7)
        fourierRenderableSeries.xAxisId = axisX2Id
        fourierRenderableSeries.yAxisId = axisY2Id
        fourierRenderableSeries.dataSeries = fourierDataSeries
        chartSurface.attachRenderableSeries(fourierRenderableSeries)
        
        chartSurface.invalidateElement()
        
    }
    
}
