//
//  SCSMultipleSurfaceChartView.swift
//  SciChartSwiftDemo
//
//  Created by Mykola Hrybeniuk on 6/6/16.
//  Copyright © 2016 SciChart Ltd. All rights reserved.
//

import Foundation
import SciChart

class SCSMultipleSurfaceChartView: UIView {
    
    let sciChartView1 = SCSBaseChartView()
    let sciChartView2 = SCSBaseChartView()
    let rangeSync = SCIAxisRangeSyncronization()
    let sizeAxisAreaSync = SCIAxisAreaSizeSyncronization()
    let rolloverModifierSync = SCIMultiSurfaceModifier(modifierType: SCIRolloverModifier.self)
    let pinchZoomModifierSync = SCIMultiSurfaceModifier(modifierType: SCIPinchZoomModifier.self)
    let yDragModifierSync = SCIMultiSurfaceModifier(modifierType: SCIYAxisDragModifier.self)
    let xDragModifierSync = SCIMultiSurfaceModifier(modifierType: SCIXAxisDragModifier.self)
    let zoomExtendsSync = SCIMultiSurfaceModifier(modifierType: SCIZoomExtentsModifier.self)
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        completeConfiguration()
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
    }
    
    // MARK: Overrided Functions
    
    override func awakeFromNib() {
        super.awakeFromNib()
        completeConfiguration()
    }
    
    // MARK: Private Functions
    
    private func configureChartSuraface() {
        
        sciChartView1.axisYId = "Y1"
        sciChartView1.axisXId = "X1"
        
        sciChartView2.axisYId = "Y2"
        sciChartView2.axisXId = "X2"
        
        sciChartView1.translatesAutoresizingMaskIntoConstraints = false
        self.addSubview(sciChartView1)
        
        sciChartView2.translatesAutoresizingMaskIntoConstraints = false
        self.addSubview(sciChartView2)
        
        let layoutDictionary = ["SciChart1" : sciChartView1, "SciChart2" : sciChartView2]
        
        self.addConstraints(NSLayoutConstraint.constraintsWithVisualFormat("|-(0)-[SciChart1]-(0)-|",
            options: .DirectionLeadingToTrailing,
            metrics: nil,
            views: layoutDictionary))
        
        self.addConstraints(NSLayoutConstraint.constraintsWithVisualFormat("|-(0)-[SciChart2]-(0)-|",
            options: .DirectionLeadingToTrailing,
            metrics: nil,
            views: layoutDictionary))
        
        self.addConstraints(NSLayoutConstraint.constraintsWithVisualFormat("V:|-(0)-[SciChart1(SciChart2)]-(10)-[SciChart2(SciChart1)]-(0)-|",
            options: .DirectionLeadingToTrailing,
            metrics: nil,
            views: layoutDictionary))
    }
    
    
    private func addAxis() {
        
        let axisStyle = sciChartView1.generateDefaultAxisStyle()
        
        let axisX1 = SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: sciChartView1.axisXId)
        rangeSync.attachAxis(axisX1)
        sciChartView1.chartSurface.attachAxis(axisX1, isXAxis: true)
        sciChartView1.chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: sciChartView1.axisYId), isXAxis: false)
        
        let axisX2 = SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: sciChartView2.axisXId);
        rangeSync.attachAxis(axisX2)
        sciChartView2.chartSurface.attachAxis(axisX2, isXAxis: true)
        sciChartView2.chartSurface.attachAxis(SCSFactoryAxis.createDefaultNumericAxis(withAxisStyle: axisStyle, axisId: sciChartView2.axisYId), isXAxis: false)
        
    }
    
    private func addModifiers() {

        sizeAxisAreaSync.syncMode = .Right
        sizeAxisAreaSync.attachSurface(sciChartView1.chartSurface)
        sizeAxisAreaSync.attachSurface(sciChartView2.chartSurface)
        
        var rolloverModifier = rolloverModifierSync.modifierForSurface(sciChartView1.chartSurface)
        var zoomExtendsModifier = zoomExtendsSync.modifierForSurface(sciChartView1.chartSurface)
        var yDragModifier = yDragModifierSync.modifierForSurface(sciChartView1.chartSurface)
        if let yDragM = yDragModifier as? SCIYAxisDragModifier {
            yDragM.axisId = sciChartView1.axisYId
            yDragM.dragMode = .Pan;
        }
        var xDragModifier = xDragModifierSync.modifierForSurface(sciChartView1.chartSurface)
        if let xDragM = xDragModifier as? SCIXAxisDragModifier {
            xDragM.axisId = sciChartView1.axisXId
            xDragM.dragMode = .Pan;
        }
        var pinchModifier = pinchZoomModifierSync.modifierForSurface(sciChartView1.chartSurface)
        var modifierGroup = SCIModifierGroup(childModifiers: [rolloverModifierSync, yDragModifierSync, pinchZoomModifierSync, zoomExtendsSync, xDragModifierSync])
        sciChartView1.chartSurface.chartModifier = modifierGroup

        rolloverModifier = rolloverModifierSync.modifierForSurface(sciChartView2.chartSurface)
        zoomExtendsModifier = zoomExtendsSync.modifierForSurface(sciChartView2.chartSurface)
        yDragModifier = yDragModifierSync.modifierForSurface(sciChartView2.chartSurface)
        if let yDragM = yDragModifier as? SCIYAxisDragModifier {
            yDragM.axisId = sciChartView2.axisYId
            yDragM.dragMode = .Pan;
        }
        xDragModifier = xDragModifierSync.modifierForSurface(sciChartView2.chartSurface)
        if let xDragM = xDragModifier as? SCIXAxisDragModifier {
            xDragM.axisId = sciChartView2.axisXId
            xDragM.dragMode = .Pan;
        }
        pinchModifier = pinchZoomModifierSync.modifierForSurface(sciChartView2.chartSurface)
        modifierGroup = SCIModifierGroup(childModifiers: [rolloverModifierSync, yDragModifierSync, pinchZoomModifierSync, zoomExtendsSync, xDragModifierSync])
        sciChartView2.chartSurface.chartModifier = modifierGroup
    }
    
    private func addDataSeries() {
        
        let dataSeries1 = SCIXyDataSeries(XType: .Float, YType: .Float)
        SCSDataManager.putDataInto(dataSeries1)
        dataSeries1.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        let ellipseMarker = SCIEllipsePointMarker()
        ellipseMarker.drawBorder = true
        ellipseMarker.fillBrush = SCIBrushSolid(colorCode: 0xFFd6ffd7)
        ellipseMarker.height = 5
        ellipseMarker.width = 5
        
        var renderableDataSeries = SCIFastLineRenderableSeries()
        renderableDataSeries.style.pointMarker = ellipseMarker
        renderableDataSeries.style.drawPointMarkers = true
        renderableDataSeries.style.linePen = SCIPenSolid(colorCode: 0xFF99EE99, width: 0.7)
        renderableDataSeries.xAxisId = sciChartView1.axisXId
        renderableDataSeries.yAxisId = sciChartView1.axisYId
        renderableDataSeries.dataSeries = dataSeries1
        
        sciChartView1.chartSurface.attachRenderableSeries(renderableDataSeries)
        sciChartView1.chartSurface.invalidateElement()
        
        
        let dataSeries2 = SCIXyDataSeries(XType: .Float, YType: .Float)
        SCSDataManager.putDataInto(dataSeries2)
        dataSeries2.dataDistributionCalculator = SCIUserDefinedDistributionCalculator()
        
        renderableDataSeries = SCIFastLineRenderableSeries()
        renderableDataSeries.style.linePen = SCIPenSolid(colorCode: 0xFF4c8aff, width: 0.7)
        renderableDataSeries.xAxisId = sciChartView2.axisXId
        renderableDataSeries.yAxisId = sciChartView2.axisYId
        renderableDataSeries.dataSeries = dataSeries2
        
        sciChartView2.chartSurface.attachRenderableSeries(renderableDataSeries)
        sciChartView2.chartSurface.invalidateElement()
        
    }
    
    
    // MARK: Internal Functions
    
    func completeConfiguration() {
        configureChartSuraface()
        addAxis()
        addModifiers()
        addDataSeries()

    }
    
    
}
